@@ -7,9 +7,9 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: structs.lisp 10350 2005-03-02 19:25:59Z kevin $
+;;;; $Id$
 ;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -24,12 +24,12 @@
 (uffi:def-foreign-type foo-ptr (* foo))
 
 ;; tests that compilation worked
-(deftest structs.1 
+(deftest :structs.1
   (with-foreign-object (p 'foo)
     t)
   t)
 
-(deftest structs.2
+(deftest :structs.2
     (progn
       (uffi:def-foreign-type foo-struct (:struct foo))
       t)
